@@ -7,7 +7,7 @@ from sklearn.metrics import mean_squared_error, mean_absolute_error
 
 from fedot.core.data.data import InputData
 from fedot.core.data.data_split import train_test_data_setup
-from fedot.core.pipelines.node import PrimaryNode, SecondaryNode
+from fedot.core.pipelines.node import PipelineNode
 from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.pipelines.ts_wrappers import in_sample_ts_forecast
 from fedot.core.repository.dataset_types import DataTypesEnum
@@ -20,11 +20,11 @@ np.random.seed(2020)
 def get_refinement_pipeline_with_polyfit():
     """ Create 4-level pipeline with decompose operation """
 
-    node_polyfit = PrimaryNode('polyfit')
+    node_polyfit = PipelineNode('polyfit')
     node_polyfit.parameters = {'degree': 2}
-    node_lagged = PrimaryNode('lagged')
-    node_decompose = SecondaryNode('decompose', nodes_from=[node_lagged, node_polyfit])
-    node_dtreg = SecondaryNode('dtreg', nodes_from=[node_decompose])
+    node_lagged = PipelineNode('lagged')
+    node_decompose = PipelineNode('decompose', nodes_from=[node_lagged, node_polyfit])
+    node_dtreg = PipelineNode('dtreg', nodes_from=[node_decompose])
     node_dtreg.parameters = {'max_depth': 3}
 
     # Pipelines with different outputs
@@ -32,7 +32,7 @@ def get_refinement_pipeline_with_polyfit():
     pipeline_with_main_finish = Pipeline(node_polyfit)
 
     # Combining branches with different targets (T and T_decomposed)
-    final_node = SecondaryNode('ridge', nodes_from=[node_polyfit, node_dtreg])
+    final_node = PipelineNode('ridge', nodes_from=[node_polyfit, node_dtreg])
 
     pipeline = Pipeline(final_node)
     return pipeline_with_main_finish, pipeline_with_decompose_finish, pipeline
@@ -41,11 +41,11 @@ def get_refinement_pipeline_with_polyfit():
 def get_refinement_pipeline(lagged):
     """ Create 4-level pipeline with decompose operation """
 
-    node_lagged = PrimaryNode('lagged')
+    node_lagged = PipelineNode('lagged')
     node_lagged.parameters = {'window_size': lagged}
-    node_lasso = SecondaryNode('lasso', nodes_from=[node_lagged])
-    node_decompose = SecondaryNode('decompose', nodes_from=[node_lagged, node_lasso])
-    node_dtreg = SecondaryNode('dtreg', nodes_from=[node_decompose])
+    node_lasso = PipelineNode('lasso', nodes_from=[node_lagged])
+    node_decompose = PipelineNode('decompose', nodes_from=[node_lagged, node_lasso])
+    node_dtreg = PipelineNode('dtreg', nodes_from=[node_decompose])
     node_dtreg.parameters = {'max_depth': 3}
 
     # Pipelines with different outputs
@@ -53,7 +53,7 @@ def get_refinement_pipeline(lagged):
     pipeline_with_main_finish = Pipeline(node_lasso)
 
     # Combining branches with different targets (T and T_decomposed)
-    final_node = SecondaryNode('ridge', nodes_from=[node_lasso, node_dtreg])
+    final_node = PipelineNode('ridge', nodes_from=[node_lasso, node_dtreg])
 
     pipeline = Pipeline(final_node)
     return pipeline_with_main_finish, pipeline_with_decompose_finish, pipeline
@@ -62,12 +62,12 @@ def get_refinement_pipeline(lagged):
 def get_non_refinement_pipeline(lagged):
     """ Create 4-level pipeline without decompose operation """
 
-    node_lagged = PrimaryNode('lagged')
+    node_lagged = PipelineNode('lagged')
     node_lagged.parameters = {'window_size': lagged}
-    node_lasso = SecondaryNode('lasso', nodes_from=[node_lagged])
-    node_dtreg = SecondaryNode('dtreg', nodes_from=[node_lagged])
+    node_lasso = PipelineNode('lasso', nodes_from=[node_lagged])
+    node_dtreg = PipelineNode('dtreg', nodes_from=[node_lagged])
     node_dtreg.parameters = {'max_depth': 3}
-    final_node = SecondaryNode('ridge', nodes_from=[node_lasso, node_dtreg])
+    final_node = PipelineNode('ridge', nodes_from=[node_lasso, node_dtreg])
 
     pipeline = Pipeline(final_node)
     return pipeline
