@@ -5,7 +5,7 @@ from typing import Any, Optional, Sequence, Union
 from fedot.api.main import Fedot
 from fedot.core.composer.gp_composer.specific_operators import boosting_mutation, parameter_change_mutation
 from fedot.core.dag.graph import Graph
-from fedot.core.optimisers.gp_comp.evaluation import SimpleDispatcher
+from fedot.core.optimisers.gp_comp.evaluation import SequentialDispatcher
 from fedot.core.optimisers.gp_comp.operators.mutation import MutationTypesEnum, Mutation
 from fedot.core.optimisers.objective import Objective, ObjectiveFunction
 from fedot.core.optimisers.opt_history_objects.individual import Individual
@@ -35,7 +35,7 @@ class RandomMutationSearchOptimizer(GraphOptimizer):
     def optimise(self, objective: ObjectiveFunction):
 
         timer = OptimisationTimer(timeout=self.requirements.timeout)
-        dispatcher = SimpleDispatcher(self.graph_generation_params.adapter)
+        dispatcher = SequentialDispatcher(self.graph_generation_params.adapter)
         evaluator = dispatcher.dispatch(objective, timer)
 
         num_iter = 0
