@@ -6,7 +6,7 @@ from sklearn.datasets import make_moons
 from examples.simple.classification.classification_pipelines import classification_svc_complex_pipeline
 from fedot.api.main import Fedot
 from fedot.core.data.data import InputData
-from fedot.core.pipelines.node import PrimaryNode, SecondaryNode
+from fedot.core.pipelines.node import PipelineNode
 from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.repository.dataset_types import DataTypesEnum
 from fedot.core.repository.tasks import Task, TaskTypesEnum
@@ -27,7 +27,7 @@ def run_one_model_with_specific_evaluation_mode(train_data, test_data, mode: str
         baseline_model = Fedot(problem=problem, preset='gpu')
     else:
         baseline_model = Fedot(problem=problem)
-    svc_node_with_custom_params = PrimaryNode('svc')
+    svc_node_with_custom_params = PipelineNode('svc')
     # the custom params are needed to make probability evaluation available
     # otherwise an error is occurred
     svc_node_with_custom_params.parameters = \
