@@ -2,7 +2,7 @@ from sklearn.metrics import roc_auc_score as roc_auc
 
 from cases.data.data_utils import get_scoring_case_data_paths
 from fedot.core.data.data import InputData
-from fedot.core.pipelines.node import PrimaryNode
+from fedot.core.pipelines.node import PipelineNode
 from fedot.core.pipelines.pipeline import Pipeline
 from fedot.utilities.project_import_export import export_project_to_zip, import_project_from_zip
 
@@ -11,7 +11,7 @@ if __name__ == '__main__':
     train_data = InputData.from_csv(train_file_path)
     test_data = InputData.from_csv(test_file_path)
 
-    pipeline = Pipeline(PrimaryNode('rf'))
+    pipeline = Pipeline(PipelineNode('rf'))
 
     # Export project to zipfile to directory
     export_project_to_zip(zip_name='example', opt_history=None,
