@@ -1,4 +1,4 @@
-from fedot.core.pipelines.node import PrimaryNode, SecondaryNode
+from fedot.core.pipelines.node import PipelineNode
 from fedot.core.pipelines.pipeline import Pipeline
 
 
@@ -13,18 +13,18 @@ def cnn_composite_pipeline(composite_flag: bool = True) -> Pipeline:
 
     :param composite_flag:  add additional random forest estimator
     """
-    node_first = PrimaryNode('cnn')
+    node_first = PipelineNode('cnn')
     node_first.parameters = {'architecture': 'deep',
                              'epochs': 15,
                              'batch_size': 128}
-    node_second = PrimaryNode('cnn')
+    node_second = PipelineNode('cnn')
     node_second.parameters = {'architecture_type': 'simplified',
                               'epochs': 10,
                               'batch_size': 128}
-    node_final = SecondaryNode('rf', nodes_from=[node_first, node_second])
+    node_final = PipelineNode('rf', nodes_from=[node_first, node_second])
 
     if not composite_flag:
-        node_final = SecondaryNode('rf', nodes_from=[node_first])
+        node_final = PipelineNode('rf', nodes_from=[node_first])
 
     pipeline = Pipeline(node_final)
     return pipeline
@@ -41,12 +41,12 @@ def classification_pipeline_with_balancing(custom_params=None):
 
     :param custom_params:  custom parameters for resample node
     """
-    node_resample = PrimaryNode(operation_type='resample')
+    node_resample = PipelineNode(operation_type='resample')
 
     if custom_params is not None:
         node_resample.parameters = custom_params
 
-    graph = SecondaryNode(operation_type='logit', nodes_from=[node_resample])
+    graph = PipelineNode(operation_type='logit', nodes_from=[node_resample])
 
     return Pipeline(graph)
 
@@ -60,7 +60,7 @@ def classification_pipeline_without_balancing():
 
     Where logit - logistic_regression
     """
-    node = PrimaryNode(operation_type='logit')
+    node = PipelineNode(operation_type='logit')
 
     return Pipeline(node)
 
@@ -73,9 +73,9 @@ def classification_complex_pipeline():
       :width: 55%
 
     """
-    first = PrimaryNode(operation_type='rf')
-    second = PrimaryNode(operation_type='knn')
-    final = SecondaryNode(operation_type='logit',
+    first = PipelineNode(operation_type='rf')
+    second = PipelineNode(operation_type='knn')
+    final = PipelineNode(operation_type='logit',
                           nodes_from=[first, second])
 
     pipeline = Pipeline(final)
@@ -91,8 +91,8 @@ def classification_random_forest_pipeline():
       :width: 55%
 
     """
-    node_scaling = PrimaryNode('scaling')
-    node_final = SecondaryNode('rf', nodes_from=[node_scaling])
+    node_scaling = PipelineNode('scaling')
+    node_final = PipelineNode('rf', nodes_from=[node_scaling])
     return Pipeline(node_final)
 
 
@@ -104,9 +104,9 @@ def classification_isolation_forest_pipeline():
       :width: 55%
 
     """
-    node_first = PrimaryNode('scaling')
-    node_second = SecondaryNode('isolation_forest_class', nodes_from=[node_first])
-    node_final = SecondaryNode('rf', nodes_from=[node_second])
+    node_first = PipelineNode('scaling')
+    node_second = PipelineNode('isolation_forest_class', nodes_from=[node_first])
+    node_final = PipelineNode('rf', nodes_from=[node_second])
     return Pipeline(node_final)
 
 
@@ -122,20 +122,20 @@ def classification_svc_complex_pipeline():
 
     """
 
-    svc_primary_node = PrimaryNode('svc')
+    svc_primary_node = PipelineNode('svc')
     svc_primary_node.parameters = dict(probability=True)
-    logit_secondary_node = SecondaryNode('logit', nodes_from=[svc_primary_node])
+    logit_secondary_node = PipelineNode('logit', nodes_from=[svc_primary_node])
 
-    svc_node_with_custom_params = PrimaryNode('svc')
+    svc_node_with_custom_params = PipelineNode('svc')
     svc_node_with_custom_params.parameters = dict(kernel='rbf', C=10,
                                                      gamma=1, cache_size=2000,
                                                      probability=True)
-    logit_secondary_node_2 = SecondaryNode('logit', nodes_from=[svc_node_with_custom_params])
+    logit_secondary_node_2 = PipelineNode('logit', nodes_from=[svc_node_with_custom_params])
 
-    knn_primary_node = PrimaryNode('knn')
-    knn_secondary_node = SecondaryNode('knn', nodes_from=[knn_primary_node, logit_secondary_node])
+    knn_primary_node = PipelineNode('knn')
+    knn_secondary_node = PipelineNode('knn', nodes_from=[knn_primary_node, logit_secondary_node])
 
-    rf_node = SecondaryNode('rf', nodes_from=[logit_secondary_node_2, knn_secondary_node])
+    rf_node = PipelineNode('rf', nodes_from=[logit_secondary_node_2, knn_secondary_node])
 
     preset_pipeline = Pipeline(rf_node)
 
@@ -152,14 +152,14 @@ def classification_three_depth_manual_pipeline():
     Where rf - xg boost classifier, logit - logistic regression, knn - K nearest neighbors classifier,
     qda - discriminant analysis
    """
-    logit_node_primary = PrimaryNode('logit')
-    xgb_node_primary = PrimaryNode('rf')
-    xgb_node_primary_second = PrimaryNode('rf')
+    logit_node_primary = PipelineNode('logit')
+    xgb_node_primary = PipelineNode('rf')
+    xgb_node_primary_second = PipelineNode('rf')
 
-    qda_node_third = SecondaryNode('qda', nodes_from=[xgb_node_primary_second])
-    knn_node_third = SecondaryNode('knn', nodes_from=[logit_node_primary, xgb_node_primary])
+    qda_node_third = PipelineNode('qda', nodes_from=[xgb_node_primary_second])
+    knn_node_third = PipelineNode('knn', nodes_from=[logit_node_primary, xgb_node_primary])
 
-    knn_root = SecondaryNode('knn', nodes_from=[qda_node_third, knn_node_third])
+    knn_root = PipelineNode('knn', nodes_from=[qda_node_third, knn_node_third])
 
     pipeline = Pipeline(knn_root)
 
@@ -179,11 +179,11 @@ def classification_rf_complex_pipeline():
     pipeline = Pipeline()
 
     root_of_tree, root_child_first, root_child_second = \
-        [SecondaryNode(model) for model in ('rf', 'rf', 'knn')]
+        [PipelineNode(model) for model in ('rf', 'rf', 'knn')]
 
     for root_node_child in (root_child_first, root_child_second):
         for requirement_model in ('logit', 'lda'):
-            new_node = PrimaryNode(requirement_model)
+            new_node = PipelineNode(requirement_model)
             root_node_child.nodes_from.append(new_node)
             pipeline.add_node(new_node)
         pipeline.add_node(root_node_child)
