@@ -5,8 +5,6 @@ import pandas as pd
 from fedot.api.main import Fedot
 from fedot.core.data.data import InputData
 from fedot.core.data.data_split import train_test_data_setup
-from fedot.core.pipelines.node import PrimaryNode, SecondaryNode
-from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.repository.dataset_types import DataTypesEnum
 from fedot.core.repository.tasks import TsForecastingParams, Task, TaskTypesEnum
 from fedot.core.utils import fedot_project_root
@@ -21,7 +19,7 @@ datasets = {
 
 
 def run_ts_forecasting_example(dataset='australia', horizon: int = 30, validation_blocks=2, timeout: float = None,
-                               visualization=False):
+                               visualization=False, with_tuning=True):
     time_series = pd.read_csv(datasets[dataset])
 
     task = Task(TaskTypesEnum.ts_forecasting,
@@ -44,6 +42,7 @@ def run_ts_forecasting_example(dataset='australia', horizon: int = 30, validatio
                   task_params=task.task_params,
                   timeout=timeout,
                   n_jobs=1,
+                  with_tuning=with_tuning,
                   cv_folds=2, validation_blocks=validation_blocks, preset='fast_train')
 
     # run AutoML model design in the same way
