@@ -1,7 +1,6 @@
 from typing import List
 
 from fedot.api.api_utils.assumptions.operations_filter import OperationsFilter
-from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.pipelines.pipeline_builder import PipelineBuilder
 from fedot.core.repository.operation_types_repository import OperationTypesRepository
 from fedot.core.repository.tasks import Task, TaskTypesEnum
@@ -14,13 +13,13 @@ class TaskAssumptions:
         self.repo = repository
 
     @staticmethod
-    def for_task(task: Task, repository: OperationTypesRepository):
+    def for_task(task: Task, repository: OperationTypesRepository) -> 'TaskAssumptions':
         assumptions_by_task = {
             TaskTypesEnum.classification: ClassificationAssumptions,
             TaskTypesEnum.regression: RegressionAssumptions,
             TaskTypesEnum.ts_forecasting: TSForecastingAssumptions,
         }
-        assumptions_cls = assumptions_by_task.get(task.task_type)
+        assumptions_cls: TaskAssumptions = assumptions_by_task.get(task.task_type)
         if not assumptions_cls:
             raise NotImplementedError(f"Don't have assumptions for task type: {task.task_type}")
         return assumptions_cls(repository)
@@ -49,26 +48,26 @@ class TSForecastingAssumptions(TaskAssumptions):
         return {
             'glm_ridge':
                 PipelineBuilder()
-                .add_branch('glm', 'lagged')
-                .add_node('ridge', branch_idx=1)
-                .join_branches('ridge'),
+                    .add_branch('glm', 'lagged')
+                    .add_node('ridge', branch_idx=1)
+                    .join_branches('ridge'),
             'lagged_ridge':
                 PipelineBuilder()
-                .add_sequence('lagged', 'ridge'),
+                    .add_sequence('lagged', 'ridge'),
             'polyfit_ridge':
                 PipelineBuilder()
-                .add_branch('polyfit', 'lagged')
-                .grow_branches(None, 'ridge')
-                .join_branches('ridge'),
+                    .add_branch('polyfit', 'lagged')
+                    .grow_branches(None, 'ridge')
+                    .join_branches('ridge'),
             'smoothing_ar':
                 PipelineBuilder()
-                .add_sequence('smoothing', 'ar'),
+                    .add_sequence('smoothing', 'ar'),
         }
 
     def ensemble_operation(self) -> str:
         return 'ridge'
 
-    def processing_builders(self) -> List[Pipeline]:
+    def processing_builders(self) -> List[PipelineBuilder]:
         return list(self.builders.values())
 
     def fallback_builder(self, operations_filter: OperationsFilter) -> PipelineBuilder:
@@ -93,7 +92,7 @@ class RegressionAssumptions(TaskAssumptions):
     def ensemble_operation(self) -> str:
         return 'rfr'
 
-    def processing_builders(self) -> List[Pipeline]:
+    def processing_builders(self) -> List[PipelineBuilder]:
         return list(self.builders.values())
 
     def fallback_builder(self, operations_filter: OperationsFilter) -> PipelineBuilder:
@@ -115,7 +114,7 @@ class ClassificationAssumptions(TaskAssumptions):
     def ensemble_operation(self) -> str:
         return 'rf'
 
-    def processing_builders(self) -> List[Pipeline]:
+    def processing_builders(self) -> List[PipelineBuilder]:
         return list(self.builders.values())
 
     def fallback_builder(self, operations_filter: OperationsFilter) -> PipelineBuilder:
