@@ -12,21 +12,24 @@ from fedot.api.api_utils.data_definition import FeaturesType, TargetType
 from fedot.api.api_utils.metrics import ApiMetrics
 from fedot.api.api_utils.params import ApiParams
 from fedot.api.api_utils.predefined_model import PredefinedModel
-from fedot.core.constants import DEFAULT_API_TIMEOUT_MINUTES
+from fedot.core.constants import DEFAULT_API_TIMEOUT_MINUTES, DEFAULT_TUNING_ITERATIONS_NUMBER
 from fedot.core.data.data import InputData, OutputData
 from fedot.core.data.multi_modal import MultiModalData
 from fedot.core.data.visualisation import plot_biplot, plot_forecast, plot_roc_auc
 from fedot.core.optimisers.opt_history_objects.opt_history import OptHistory
 from fedot.core.pipelines.pipeline import Pipeline
-from fedot.core.pipelines.ts_wrappers import out_of_sample_ts_forecast, convert_forecast_to_output
+from fedot.core.pipelines.ts_wrappers import convert_forecast_to_output, out_of_sample_ts_forecast
+from fedot.core.pipelines.tuning.tuner_builder import TunerBuilder
+from fedot.core.pipelines.tuning.unified import PipelineTuner
 from fedot.core.repository.quality_metrics_repository import MetricsRepository
 from fedot.core.repository.tasks import TaskParams, TaskTypesEnum
 from fedot.core.utilities.data_structures import ensure_wrapped_in_sequence
 from fedot.core.visualisation.opt_viz_extra import visualise_pareto
 from fedot.explainability.explainer_template import Explainer
 from fedot.explainability.explainers import explain_pipeline
-from fedot.preprocessing.preprocessing import merge_preprocessors
+from fedot.preprocessing.base_preprocessing import BasePreprocessor
 from fedot.remote.remote_evaluator import RemoteEvaluator
+from fedot.utilities.memory import MemoryAnalytics
 from fedot.utilities.project_import_export import export_project_to_zip, import_project_from_zip
 
 NOT_FITTED_ERR_MSG = 'Model not fitted yet'
@@ -63,6 +66,7 @@ class Fedot:
         safe_mode: if set ``True`` it will cut large datasets to prevent memory overflow and use label encoder
             instead of oneHot encoder if summary cardinality of categorical features is high.
         n_jobs: num of ``n_jobs`` for parallelization (``-1`` for use all cpu's)
+        parallelization_mode: type of evaluation for candidate solution groups (populational or sequential)
         max_depth: max depth of the pipeline
         max_arity: max arity of the pipeline nodes
         pop_size: population size for composer
@@ -94,6 +98,7 @@ class Fedot:
                 - ``ts`` -> A special preset with models for time series forecasting task.
                 - ``automl`` -> A special preset with only AutoML libraries such as TPOT and H2O as operations.
 
+        use_input_preprocessing: bool indicating whether to do preprocessing of further given data, enabled by default.
         use_pipelines_cache: bool indicating whether to use pipeline structures caching, enabled by default.
         use_preprocessing_cache: bool indicating whether to use optional preprocessors caching, enabled by default.
         cache_folder: path to the place where cache files should be stored (if any cache is enabled).
@@ -106,7 +111,8 @@ class Fedot:
                  task_params: TaskParams = None,
                  seed=None, logging_level: int = logging.ERROR,
                  safe_mode=False,
-                 n_jobs: int = 1,
+                 n_jobs: int = -1,
+                 parallelization_mode: str = 'populational',
                  **composer_tuner_params
                  ):
 
@@ -118,16 +124,21 @@ class Fedot:
         # Define parameters, that were set via init in init
         input_params = {'problem': self.metrics.main_problem, 'timeout': timeout,
                         'composer_tuner_params': composer_tuner_params, 'task_params': task_params,
-                        'seed': seed, 'logging_level': logging_level, 'n_jobs': n_jobs}
+                        'seed': seed, 'logging_level': logging_level,
+                        'n_jobs': n_jobs, 'parallelization_mode': parallelization_mode}
         self.params.initialize_params(input_params)
 
         # Initialize ApiComposer's cache parameters via ApiParams
-        self.api_composer.init_cache(self.params.api_params['use_pipelines_cache'],
-                                     self.params.api_params['use_preprocessing_cache'],
-                                     self.params.api_params['cache_folder'])
+        self.api_composer.init_cache(use_pipelines_cache=self.params.api_params['use_pipelines_cache'],
+                                     use_input_preprocessing=self.params.api_params['use_input_preprocessing'],
+                                     use_preprocessing_cache=self.params.api_params['use_preprocessing_cache'],
+                                     cache_folder=self.params.api_params['cache_folder'])
+        self.tuner_requirements = None
 
         # Initialize data processors for data preprocessing and preliminary data analysis
-        self.data_processor = ApiDataProcessor(task=self.params.api_params['task'])
+        self.data_processor = ApiDataProcessor(task=self.params.api_params['task'],
+                                               use_input_preprocessing=self.params.api_params[
+                                                   'use_input_preprocessing'])
         self.data_analyser = DataAnalyser(safe_mode=safe_mode)
 
         self.target: Optional[TargetType] = None
@@ -145,40 +156,58 @@ class Fedot:
             features: FeaturesType,
             target: TargetType = 'target',
             predefined_model: Union[str, Pipeline] = None) -> Pipeline:
-        """Fits the graph with a predefined structure or compose and fit the new graph
+        """Composes and fits a new pipeline, or fits a predefined one.
 
         Args:
-            features: the array with features of train data
-            target: the array with target values of train data
-            predefined_model: the name of the atomic model or Pipeline instance.
-                If argument is ``auto``, perform initial assumption generation and then fit the pipeline
+            features: train data feature values in one of the supported features formats.
+            target: train data target values in one of the supported target formats.
+            predefined_model: the name of a single model or a :class:`Pipeline` instance, or ``"auto"``.
+                With any value specified, the method does not perform composing and tuning.
+                In case of ``"auto"``, the method generates a single initial assumption and then fits
+                the created pipeline.
 
         Returns:
-            Pipeline object
+            :class:`Pipeline` object.
 
         """
+
+        MemoryAnalytics.start()
+
         self.target = target
 
         self.train_data = self.data_processor.define_data(features=features, target=target, is_predict=False)
+        if self.params.api_params['use_input_preprocessing']:
+            # Launch data analyser - it gives recommendations for data preprocessing
+            recommendations = self.data_analyser.give_recommendation(self.train_data)
+            self.data_processor.accept_and_apply_recommendations(self.train_data, recommendations)
+            self.params.accept_and_apply_recommendations(self.train_data, recommendations)
+        else:
+            recommendations = None
 
-        # Launch data analyser - it gives recommendations for data preprocessing
-        full_train_not_preprocessed = deepcopy(self.train_data)
-        recommendations = self.data_analyser.give_recommendation(self.train_data)
-        self.data_processor.accept_and_apply_recommendations(self.train_data, recommendations)
-        self.params.accept_and_apply_recommendations(self.train_data, recommendations)
         self._init_remote_if_necessary()
-        self.params.update_available_operations_by_preset(self.train_data)
+
+        if self.params.api_params['preset'] != 'auto':
+            self.params.update_available_operations_by_preset(self.train_data)
+
         self.params.api_params['train_data'] = self.train_data
 
         if predefined_model is not None:
+            self.api_composer.set_tuner_requirements(**self.params.api_params)
+
             # Fit predefined model and return it without composing
             self.current_pipeline = PredefinedModel(predefined_model,
                                                     self.train_data,
-                                                    self.params.api_params['logger']).fit()
+                                                    self.params.api_params['logger'],
+                                                    use_input_preprocessing=self.params.api_params[
+                                                        'use_input_preprocessing']).fit()
         else:
             self.current_pipeline, self.best_models, self.history = \
                 self.api_composer.obtain_model(**self.params.api_params)
 
+            if self.current_pipeline is None:
+                raise ValueError('No models were found')
+
+            full_train_not_preprocessed = deepcopy(self.train_data)
             # Final fit for obtained pipeline on full dataset
             if self.history and not self.history.is_empty() or not self.current_pipeline.is_fitted:
                 self._train_pipeline_on_full_dataset(recommendations, full_train_not_preprocessed)
@@ -187,11 +216,65 @@ class Fedot:
                 self.params.api_params['logger'].message('Already fitted initial pipeline is used')
 
         # Store data encoder in the pipeline if it is required
-        self.current_pipeline.preprocessor = merge_preprocessors(self.data_processor.preprocessor,
-                                                                 self.current_pipeline.preprocessor)
+        self.current_pipeline.preprocessor = BasePreprocessor.merge_preprocessors(
+            self.data_processor.preprocessor, self.current_pipeline.preprocessor)
 
         self.params.api_params['logger'].message(f'Final pipeline: {self.current_pipeline.structure}')
 
+        MemoryAnalytics.finish()
+
+        return self.current_pipeline
+
+    def tune(self,
+             input_data: InputData = None,
+             metric_name: str = None,
+             iterations: int = DEFAULT_TUNING_ITERATIONS_NUMBER,
+             timeout: Optional[float] = None,
+             cv_folds: int = None,
+             n_jobs: int = None,
+             show_progress: bool = False) -> Pipeline:
+        """Method for hyperparameters tuning of current pipeline
+
+        Args:
+            input_data: data for tuning pipeline
+            metric_name: name of metric for quality tuning
+            iterations: numbers of tuning iterations
+            timeout: time for tuning (in minutes). If ``None`` or ``-1`` means tuning until max iteration reach
+            cv_folds: number of folds on data for cross-validation.
+            n_jobs: num of ``n_jobs`` for parallelization (``-1`` for use all cpu's)
+            show_progress: shows progress of tuning if true
+
+        Returns:
+            Pipeline object
+
+        """
+        if self.current_pipeline is None:
+            raise ValueError(NOT_FITTED_ERR_MSG)
+
+        input_data = input_data or self.train_data
+
+        if metric_name is None:
+            metric_name = self.metrics.get_problem_metrics()[0]
+
+        if cv_folds is not None:
+            self.api_composer.tuner_requirements.cv_folds = cv_folds
+
+        if n_jobs is not None:
+            self.api_composer.tuner_requirements.n_jobs = n_jobs
+
+        pipeline_tuner = TunerBuilder(self.params.task) \
+            .with_tuner(PipelineTuner) \
+            .with_requirements(self.api_composer.tuner_requirements) \
+            .with_metric(self.metrics.get_metrics_mapping(metric_name)) \
+            .with_iterations(iterations) \
+            .with_timeout(timeout) \
+            .build(input_data)
+
+        self.current_pipeline = pipeline_tuner.tune(self.current_pipeline, show_progress)
+        self.api_composer.was_tuned = pipeline_tuner.was_tuned
+
+        # Tuner returns a not fitted pipeline, and it is required to fit on train dataset
+        self.current_pipeline.fit(self.train_data)
         return self.current_pipeline
 
     def predict(self,
@@ -285,7 +368,7 @@ class Fedot:
         self._check_forecast_applicable()
 
         forecast_length = self.train_data.task.task_params.forecast_length
-        horizon = horizon if horizon is not None else forecast_length
+        horizon = horizon or forecast_length
         if pre_history is None:
             pre_history = self.train_data
             pre_history.target = None
@@ -312,12 +395,12 @@ class Fedot:
         Args:
             path: path to ``json`` file with model
         """
-        self.current_pipeline = Pipeline()
+        self.current_pipeline = Pipeline(use_input_preprocessing=self.params.api_params['use_input_preprocessing'])
         self.current_pipeline.load(path)
         self.data_processor.preprocessor = self.current_pipeline.preprocessor
 
     def plot_pareto(self):
-        metric_names = self.params.metric_to_compose
+        metric_names = self.api_composer.metric_names
         # archive_history stores archives of the best models.
         # Each archive is sorted from the best to the worst model,
         # so the best_candidates is sorted too.
@@ -359,12 +442,12 @@ class Fedot:
         """Gets quality metrics for the fitted graph
 
         Args:
-            target: the array with target values of test data
-            metric_names: the names of required metrics
+            target: the array with target values of test data. If None, target specified for fit is used
+            metric_names: the names of required metrics.
             in_sample: used for time-series forecasting.
                 If True prediction will be obtained as ``.predict(..., in_sample=True)``.
             validation_blocks: number of validation blocks for in-sample forecast.
-                If ``validation_blocks = None`` uses number of validation blocks set during model initialization
+                If None uses number of validation blocks set during model initialisation
                 (default is 2).
 
         Returns:
@@ -383,7 +466,6 @@ class Fedot:
             else:
                 self.test_data.target = target[:len(self.prediction.predict)]
 
-        # TODO change to sklearn metrics
         metric_names = ensure_wrapped_in_sequence(metric_names)
 
         calculated_metrics = dict()
@@ -478,16 +560,17 @@ class Fedot:
             if isinstance(self.target, str) and remote.remote_task_params.target is None:
                 remote.remote_task_params.target = self.target
 
-    def _train_pipeline_on_full_dataset(self, recommendations: dict, full_train_not_preprocessed):
+    def _train_pipeline_on_full_dataset(self, recommendations: Optional[dict],
+                                        full_train_not_preprocessed: Union[InputData, MultiModalData]):
         """Applies training procedure for obtained pipeline if dataset was clipped
         """
 
-        if recommendations:
+        if recommendations is not None:
             # if data was cut we need to refit pipeline on full data
             self.data_processor.accept_and_apply_recommendations(full_train_not_preprocessed,
                                                                  {k: v for k, v in recommendations.items()
                                                                   if k != 'cut'})
         self.current_pipeline.fit(
             full_train_not_preprocessed,
-            n_jobs=self.params.api_params['n_jobs'],
+            n_jobs=self.params.api_params['n_jobs']
         )
