@@ -11,8 +11,8 @@ from fedot.core.optimisers.fitness import Fitness
 from fedot.core.optimisers.gp_comp.pipeline_composer_requirements import PipelineComposerRequirements
 from fedot.core.optimisers.objective import Objective, ObjectiveFunction
 from fedot.core.optimisers.optimizer import GraphOptimizer
-from fedot.core.pipelines.node import SecondaryNode, PrimaryNode
-from fedot.core.pipelines.pipeline import Node, Pipeline
+from fedot.core.pipelines.node import PipelineNode
+from fedot.core.pipelines.pipeline import Pipeline
 
 
 class RandomSearchComposer(Composer):
@@ -30,7 +30,7 @@ class RandomSearchComposer(Composer):
         return best_pipeline
 
 
-def nodes_to_pipeline(nodes: List[Node]) -> Pipeline:
+def nodes_to_pipeline(nodes: List[PipelineNode]) -> Pipeline:
     pipeline = Pipeline()
     [pipeline.add_node(nodes) for nodes in nodes]
     return pipeline
@@ -39,9 +39,8 @@ def nodes_to_pipeline(nodes: List[Node]) -> Pipeline:
 class RandomGraphFactory:
     def __init__(self,
                  primary_candidates: Sequence[Any], secondary_candidates: Sequence[Any],
-                 primary_node_func: Callable = PrimaryNode, secondary_node_func: Callable = SecondaryNode):
-        self.__primary_node_func = primary_node_func
-        self.__secondary_node_func = secondary_node_func
+                 node_func: Callable = PipelineNode):
+        self.__node_func = node_func
         self.__primary_candidates = list(primary_candidates)
         self.__secondary_candidates = list(secondary_candidates)
 
@@ -54,21 +53,21 @@ class RandomGraphFactory:
         # random primary nodes
         num_of_primary = randint(1, len(self.__primary_candidates))
         for _ in range(num_of_primary):
-            new_set.append(self.random_primary())
+            new_set.append(self.random_node())
 
         # random final node
         if len(new_set) > 1:
             parent_nodes = copy(new_set)
-            final_node = self.random_secondary(parent_nodes)
+            final_node = self.random_node(parent_nodes)
             new_set.append(final_node)
 
         return nodes_to_pipeline(new_set)
 
-    def random_primary(self):
-        return self.__primary_node_func(random.choice(self.__primary_candidates))
-
-    def random_secondary(self, parent_nodes):
-        return self.__secondary_node_func(random.choice(self.__secondary_candidates), parent_nodes)
+    def random_node(self, parent_nodes=None):
+        if parent_nodes:
+            return self.__node_func(random.choice(self.__secondary_candidates), parent_nodes)
+        else:
+            return self.__node_func(random.choice(self.__primary_candidates))
 
 
 class RandomSearchOptimizer(GraphOptimizer):
