@@ -9,6 +9,7 @@ from typing import Optional, Tuple, Union
 
 from fedot.core.utilities.singleton_meta import SingletonMeta
 from fedot.core.utils import default_fedot_data_dir
+from fedot.utilities.debug import is_test_session
 
 DEFAULT_LOG_PATH = pathlib.Path(default_fedot_data_dir(), 'log.log')
 
@@ -171,13 +172,46 @@ class LoggerAdapter(logging.LoggerAdapter):
         self.logger.setLevel(self.logging_level)
         return '%s - %s' % (self.extra['prefix'], msg), kwargs
 
-    def message(self, message: str):
+    def debug(self, msg, *args, **kwargs):
+        raise_if_test(msg, **kwargs)
+        super().debug(msg, *args, **kwargs)
+
+    def info(self, msg, *args, **kwargs):
+        raise_if_test(msg, **kwargs)
+        super().info(msg, *args, **kwargs)
+
+    def warning(self, msg, *args, **kwargs):
+        raise_if_test(msg, **kwargs)
+        super().warning(msg, *args, **kwargs)
+
+    def error(self, msg, *args, **kwargs):
+        raise_if_test(msg, **kwargs)
+        super().error(msg, *args, **kwargs)
+
+    def exception(self, msg, *args, exc_info=True, **kwargs):
+        raise_if_test(msg, **kwargs)
+        super().exception(msg, *args, **kwargs)
+
+    def critical(self, msg, *args, **kwargs):
+        raise_if_test(msg, **kwargs)
+        super().critical(msg, *args, **kwargs)
+
+    def log(self, level, msg, *args, **kwargs):
+        """
+        Delegate a log call to the underlying logger, after adding
+        contextual information from this adapter instance.
+        """
+        raise_if_test(msg, **kwargs)
+        super().log(level, msg, *args, **kwargs)
+
+    def message(self, msg: str, **kwargs):
         """ Record the message to user.
         Message is an intermediate logging level between info and warning
         to display main info about optimization process """
+        raise_if_test(msg, **kwargs)
         message_logging_level = 45
         if message_logging_level >= self.logging_level:
-            self.critical(msg=message)
+            self.critical(msg=msg)
 
     def __str__(self):
         return f'LoggerAdapter object for {self.extra["prefix"]} module'
@@ -186,6 +220,11 @@ class LoggerAdapter(logging.LoggerAdapter):
         return self.__str__()
 
 
+def raise_if_test(msg, **kwargs):
+    if kwargs.get('raise_if_test', False) is True and is_test_session:
+        raise Exception(msg)
+
+
 def default_log(prefix: Optional[object] = 'default') -> 'LoggerAdapter':
     """ Default logger
 
