@@ -11,7 +11,6 @@ from fedot.core.pipelines.tuning.unified import PipelineTuner
 from fedot.core.repository.operation_types_repository import OperationMetaInfo, \
     atomized_model_type
 from fedot.core.utils import make_pipeline_generator
-from fedot.preprocessing.preprocessing import DataPreprocessor
 
 
 class AtomizedModel(Operation):
@@ -24,14 +23,10 @@ class AtomizedModel(Operation):
         super().__init__(operation_type=atomized_model_type())
         self.pipeline = pipeline
         self.unique_id = self.pipeline.root_node.descriptive_id
-        self.atomized_preprocessor = DataPreprocessor()
 
-    def fit(self, params: Optional[Union[OperationParameters, dict]], data: InputData,
-            use_cache: bool = True):
+    def fit(self, params: Optional[Union[OperationParameters, dict]], data: InputData):
 
         copied_input_data = deepcopy(data)
-        copied_input_data = self.atomized_preprocessor.obligatory_prepare_for_fit(copied_input_data)
-
         predicted_train = self.pipeline.fit(input_data=copied_input_data)
         fitted_atomized_operation = self.pipeline
 
@@ -42,8 +37,6 @@ class AtomizedModel(Operation):
 
         # Preprocessing applied
         copied_input_data = deepcopy(data)
-        copied_input_data = self.atomized_preprocessor.obligatory_prepare_for_predict(copied_input_data)
-
         prediction = fitted_operation.predict(input_data=copied_input_data, output_mode=output_mode)
         prediction = self.assign_tabular_column_types(prediction, output_mode)
         return prediction
@@ -56,11 +49,11 @@ class AtomizedModel(Operation):
                   input_data: InputData = None, iterations: int = 50,
                   timeout: int = 5):
         """ Method for tuning hyperparameters """
-        tuner = TunerBuilder(input_data.task)\
-            .with_tuner(PipelineTuner)\
-            .with_metric(metric_function)\
-            .with_iterations(iterations)\
-            .with_timeout(timedelta(minutes=timeout))\
+        tuner = TunerBuilder(input_data.task) \
+            .with_tuner(PipelineTuner) \
+            .with_metric(metric_function) \
+            .with_iterations(iterations) \
+            .with_timeout(timedelta(minutes=timeout)) \
             .build(input_data)
         tuned_pipeline = tuner.tune(self.pipeline)
         tuned_atomized_model = AtomizedModel(tuned_pipeline)
