@@ -46,6 +46,8 @@ class HallOfFame:
         :param population: A list of individual with a fitness attribute to
                            update the hall of fame with.
         """
+        if not population:
+            return
         for ind in population:
             if len(self) == 0 and self.maxsize != 0:
                 # Working on an empty hall of fame is problematic for the loop
