@@ -16,8 +16,8 @@ class PipelineComposerRequirements(ComposerRequirements):
     :param min_arity: min number of parents for node
     :param max_arity: max number of parents for node
 
-    :param primary: operation types for :class:`~fedot.core.pipelines.node.PrimaryNode`s
-    :param secondary: operation types for :class:`~fedot.core.pipelines.node.SecondaryNode`s
+    :param primary: operation types for primary PipelineNode
+    :param secondary: operation types for secondary PipelineNode
 
     """
 
