@@ -1,7 +1,7 @@
 from copy import deepcopy
 from datetime import timedelta
 from os import PathLike
-from typing import List, Optional, Tuple, Union, Sequence
+from typing import Optional, Tuple, Union, Sequence
 
 import func_timeout
 
@@ -18,14 +18,15 @@ from fedot.core.log import default_log
 from fedot.core.operations.data_operation import DataOperation
 from fedot.core.operations.model import Model
 from fedot.core.optimisers.timer import Timer
-from fedot.core.pipelines.node import Node, PrimaryNode, SecondaryNode
+from fedot.core.pipelines.node import PipelineNode
 from fedot.core.pipelines.template import PipelineTemplate
 from fedot.core.repository.tasks import TaskTypesEnum
 from fedot.core.utilities.serializable import Serializable
 from fedot.core.utils import copy_doc
 from fedot.core.visualisation.graph_viz import NodeColorType
 from fedot.core.visualisation.pipeline_specific_visuals import PipelineVisualizer
-from fedot.preprocessing.preprocessing import DataPreprocessor, update_indices_for_time_series
+from fedot.preprocessing.dummy_preprocessing import DummyPreprocessor
+from fedot.preprocessing.preprocessing import DataPreprocessor
 
 ERROR_PREFIX = 'Invalid pipeline configuration:'
 
@@ -35,16 +36,18 @@ class Pipeline(GraphDelegate, Serializable):
 
     Args:
         nodes: :obj:`Node` object(s)
+        use_input_preprocessing: whether to do input preprocessing or not, True by default
     """
 
-    def __init__(self, nodes: Union[Node, Sequence[Node]] = ()):
+    def __init__(self, nodes: Union[PipelineNode, Sequence[PipelineNode]] = (), use_input_preprocessing: bool = True):
         super().__init__(nodes, _graph_nodes_to_pipeline_nodes)
 
         self.computation_time = None
         self.log = default_log(self)
 
+        self.use_input_preprocessing = use_input_preprocessing  # used outside of the class
         # Define data preprocessor
-        self.preprocessor = DataPreprocessor()
+        self.preprocessor = DataPreprocessor() if use_input_preprocessing else DummyPreprocessor()
 
     def fit_from_scratch(self, input_data: Union[InputData, MultiModalData] = None):
         """[Obsolete] Method used for training the pipeline without using saved information
@@ -66,7 +69,6 @@ class Pipeline(GraphDelegate, Serializable):
 
         Args:
             input_data: data used for operations training
-            use_fitted_operations: flag defining whether to use saved information about previous executions or not
             time: time constraint for operations fitting process (in minutes)
 
         Returns:
@@ -95,7 +97,6 @@ class Pipeline(GraphDelegate, Serializable):
 
         Args:
             input_data: data used for operation training
-            use_fitted_operations: flag defining whether to use saved information about previous executions or not
             process_state_dict: dictionary used for saving required pipeline parameters
                 (which were changed inside the process) in case of operations fit time control (when process created)
             fitted_operations: list used for saving fitted operations of pipeline nodes
@@ -119,6 +120,55 @@ class Pipeline(GraphDelegate, Serializable):
             for node in self.nodes:
                 fitted_operations.append(node.fitted_operation)
 
+    def _preprocess(self, input_data: Union[InputData, MultiModalData], *, is_fit_stage: bool = True) -> Union[
+        InputData, MultiModalData]:
+        """
+        Makes obligatory and optional (if needed) steps of data preprocessing
+
+        Args:
+            input_data: to be copied and preprocessed
+            is_fit_stage: True when it's fitting stage
+
+        Returns:
+            preprocessed copy of the original data
+        """
+        copied_input_data = deepcopy(input_data)
+        if is_fit_stage:
+            copied_input_data = self.preprocessor.obligatory_prepare_for_fit(copied_input_data)
+            # Make additional preprocessing if it is needed
+            copied_input_data = self.preprocessor.optional_prepare_for_fit(pipeline=self,
+                                                                           data=copied_input_data)
+            copied_input_data = self.preprocessor.convert_indexes_for_fit(pipeline=self,
+                                                                          data=copied_input_data)
+        else:
+            copied_input_data = self.preprocessor.obligatory_prepare_for_predict(copied_input_data)
+            # Make additional preprocessing if it is needed
+            copied_input_data = self.preprocessor.optional_prepare_for_predict(pipeline=self,
+                                                                               data=copied_input_data)
+            copied_input_data = self.preprocessor.convert_indexes_for_predict(pipeline=self,
+                                                                              data=copied_input_data)
+            copied_input_data = self.preprocessor.update_indices_for_time_series(copied_input_data)
+        return copied_input_data
+
+    def _postprocess(self, copied_input_data: Optional[InputData], result: OutputData,
+                     output_mode: str = 'default') -> OutputData:
+        """
+        Postprocesses output of the model
+
+        Args:
+            copied_input_data: preprocessed copy of the original data
+            result: output of the model
+            output_mode: desired form of output for operations
+
+        Returns:
+            OutputData: postprocessed ``result`` parameter
+        """
+        result = self.preprocessor.restore_index(copied_input_data, result)
+        # Prediction should be converted into source labels (if it is needed)
+        if output_mode == 'labels':
+            result.predict = self.preprocessor.apply_inverse_target_encoding(result.predict)
+        return result
+
     def fit(self, input_data: Union[InputData, MultiModalData],
             time_constraint: Optional[timedelta] = None, n_jobs: int = 1) -> OutputData:
         """
@@ -134,13 +184,8 @@ class Pipeline(GraphDelegate, Serializable):
         """
         self.replace_n_jobs_in_nodes(n_jobs)
 
-        copied_input_data = deepcopy(input_data)
-        copied_input_data = self.preprocessor.obligatory_prepare_for_fit(copied_input_data)
-        # Make additional preprocessing if it is needed
-        copied_input_data = self.preprocessor.optional_prepare_for_fit(pipeline=self,
-                                                                       data=copied_input_data)
-        copied_input_data = self.preprocessor.convert_indexes_for_fit(pipeline=self,
-                                                                      data=copied_input_data)
+        copied_input_data = self._preprocess(input_data)
+
         copied_input_data = self._assign_data_to_nodes(copied_input_data)
         if time_constraint is None:
             train_predicted = self._fit(input_data=copied_input_data)
@@ -180,7 +225,7 @@ class Pipeline(GraphDelegate, Serializable):
             self.unfit_preprocessor()
 
     def unfit_preprocessor(self):
-        self.preprocessor = DataPreprocessor()
+        self.preprocessor = type(self.preprocessor)()
 
     def try_load_from_cache(self, cache: Optional[OperationsCache], preprocessing_cache: Optional[PreprocessingCache],
                             fold_id: Optional[int] = None):
@@ -223,23 +268,12 @@ class Pipeline(GraphDelegate, Serializable):
             raise ValueError(ex)
 
         # Make copy of the input data to avoid performing inplace operations
-        copied_input_data = deepcopy(input_data)
-        copied_input_data = self.preprocessor.obligatory_prepare_for_predict(copied_input_data)
-        # Make additional preprocessing if it is needed
-        copied_input_data = self.preprocessor.optional_prepare_for_predict(pipeline=self,
-                                                                           data=copied_input_data)
-        copied_input_data = self.preprocessor.convert_indexes_for_predict(pipeline=self,
-                                                                          data=copied_input_data)
-        copied_input_data = update_indices_for_time_series(copied_input_data)
+        copied_input_data = self._preprocess(input_data, is_fit_stage=False)
 
         copied_input_data = self._assign_data_to_nodes(copied_input_data)
-
         result = self.root_node.predict(input_data=copied_input_data, output_mode=output_mode)
 
-        result = self.preprocessor.restore_index(copied_input_data, result)
-        # Prediction should be converted into source labels (if it is needed)
-        if output_mode == 'labels':
-            result.predict = self.preprocessor.apply_inverse_target_encoding(result.predict)
+        result = self._postprocess(copied_input_data, result, output_mode)
         return result
 
     def save(self, path: str = None, create_subdir: bool = True, is_datetime_in_path: bool = False) -> Tuple[str, dict]:
@@ -278,7 +312,7 @@ class Pipeline(GraphDelegate, Serializable):
         return self
 
     @property
-    def root_node(self) -> Optional[Node]:
+    def root_node(self) -> Optional[PipelineNode]:
         """Finds pipelines sink-node
 
         Returns:
@@ -317,17 +351,17 @@ class Pipeline(GraphDelegate, Serializable):
 
     def _assign_data_to_nodes(self, input_data: Union[InputData, MultiModalData]) -> Optional[InputData]:
         """In case of provided ``input_data`` is of type :class:`MultiModalData`
-        assigns :attr:`PrimaryNode.node_data` from the ``input_data``
+        assigns :attr:`PipelineNode.node_data` from the ``input_data`` if ``PipelineNode.nodes_from`` is None
 
         Args:
-            input_data: data to assign to :attr:`PrimaryNode.node_data`
+            input_data: data to assign to :attr:`PipelineNode.node_data`
 
         Returns:
             ``None`` in case of :class:`MultiModalData` and ``input_data`` otherwise
         """
 
         if isinstance(input_data, MultiModalData):
-            for node in (n for n in self.nodes if isinstance(n, PrimaryNode)):
+            for node in (n for n in self.nodes if (isinstance(n, PipelineNode) and n.is_primary)):
                 if node.operation.operation_type in input_data:
                     node.node_data = input_data[node.operation.operation_type]
                     node.direct_set = True
@@ -370,7 +404,7 @@ class Pipeline(GraphDelegate, Serializable):
                         node.content['params']['num_threads'] = n_jobs
                         node.content['params']['n_jobs'] = n_jobs
 
-    @copy_doc(Graph)
+    @copy_doc(Graph.show)
     def show(self, save_path: Optional[Union[PathLike, str]] = None, engine: Optional[str] = None,
              node_color: Optional[NodeColorType] = None, dpi: Optional[int] = None,
              node_size_scale: Optional[float] = None, font_size_scale: Optional[float] = None,
@@ -378,7 +412,7 @@ class Pipeline(GraphDelegate, Serializable):
         PipelineVisualizer(self).visualise(save_path, engine, node_color, dpi, node_size_scale, font_size_scale)
 
 
-def _graph_nodes_to_pipeline_nodes(operator: LinkedGraph, nodes: Sequence[Node]):
+def _graph_nodes_to_pipeline_nodes(operator: LinkedGraph, nodes: Sequence[PipelineNode]):
     """
     Method to update nodes type after performing some action on the pipeline
         via GraphOperator, if any of them are of GraphNode type
@@ -390,14 +424,5 @@ def _graph_nodes_to_pipeline_nodes(operator: LinkedGraph, nodes: Sequence[Node])
     for node in nodes:
         if not isinstance(node, GraphNode):
             continue
-        if node.nodes_from and not isinstance(node, SecondaryNode):
-            operator.update_node(old_node=node,
-                                 new_node=SecondaryNode(nodes_from=node.nodes_from,
-                                                        content=node.content))
-        # TODO: avoid internal access use operator.delete_node
-        elif not node.nodes_from and not operator.node_children(node) and node != operator.root_node:
+        if not node.nodes_from and not operator.node_children(node) and node != operator.root_node:
             operator.nodes.remove(node)
-        elif not node.nodes_from and not isinstance(node, PrimaryNode):
-            operator.update_node(old_node=node,
-                                 new_node=PrimaryNode(nodes_from=node.nodes_from,
-                                                      content=node.content))
