@@ -12,12 +12,14 @@ import numpy as np
 from fedot.core.log import default_log
 from fedot.core.operations.atomized_template import AtomizedModelTemplate
 from fedot.core.operations.operation_template import OperationTemplate, check_existing_path
-from fedot.core.pipelines.node import Node, PrimaryNode, SecondaryNode
+from fedot.core.pipelines.node import PipelineNode
 
 if TYPE_CHECKING:
     from fedot.core.pipelines.pipeline import Pipeline
 
 from fedot.core.repository.operation_types_repository import atomized_model_type
+from fedot.preprocessing.dummy_preprocessing import DummyPreprocessor
+from fedot.preprocessing.preprocessing import DataPreprocessor
 
 
 class NumpyIntEncoder(json.JSONEncoder):
@@ -43,6 +45,7 @@ class PipelineTemplate:
         if pipeline is not None:
             self.depth = pipeline.depth
             self.metadata['computation_time_in_seconds'] = pipeline.computation_time
+            self.metadata['use_input_preprocessing'] = pipeline.use_input_preprocessing
 
             # Save preprocessing operations
             self.data_preprocessor = pipeline.preprocessor
@@ -54,7 +57,7 @@ class PipelineTemplate:
 
         self._pipeline_to_template(pipeline)
 
-    def _pipeline_to_template(self, pipeline):
+    def _pipeline_to_template(self, pipeline: 'Pipeline'):
         try:
             # TODO improve for graph with several roots
             self._extract_pipeline_structure(pipeline.root_node, 0, [])
@@ -62,9 +65,9 @@ class PipelineTemplate:
             self.log.info(f'Cannot export to template: {ex}')
         self.link_to_empty_pipeline = pipeline
 
-    def _extract_pipeline_structure(self, node: Node, operation_id: int, visited_nodes: List[Node]):
+    def _extract_pipeline_structure(self, node: PipelineNode, operation_id: int, visited_nodes: List[PipelineNode]):
         """
-        Recursively go through the Pipeline from 'root_node' to PrimaryNode's,
+        Recursively go through the Pipeline from 'root_node' to PipelineNode's,
         creating a OperationTemplate with unique id for each Node. In addition,
         checking whether this Node has been visited yet.
         """
@@ -91,7 +94,7 @@ class PipelineTemplate:
             self.operation_templates.append(operation_template)
             self.total_pipeline_operations[operation_template.operation_type] += 1
 
-    def export_pipeline(self, path: Optional[str] = None, root_node: Optional[Node] = None,
+    def export_pipeline(self, path: Optional[str] = None, root_node: Optional[PipelineNode] = None,
                         create_subdir: bool = True,
                         is_datetime_in_path: bool = False) -> Tuple[str, dict]:
         """
@@ -136,7 +139,7 @@ class PipelineTemplate:
 
         return json_data, dict_fitted_operations
 
-    def convert_to_dict(self, root_node: Node = None) -> dict:
+    def convert_to_dict(self, root_node: PipelineNode = None) -> dict:
         """ Generate pipeline description in a form of dictionary """
 
         json_nodes = list(map(lambda op_template: op_template.convert_to_dict(), self.operation_templates))
@@ -228,7 +231,7 @@ class PipelineTemplate:
                     else:
                         continue
                     max_pipeline_idx = cur_pipeline_idx if cur_pipeline_idx > max_pipeline_idx else max_pipeline_idx
-            folder_name = f"{max_pipeline_idx+1}{suffix}"
+            folder_name = f"{max_pipeline_idx + 1}{suffix}"
 
         path_to_dir = os.path.join(path, folder_name)
         path_to_dir = path_to_dir
@@ -294,7 +297,7 @@ class PipelineTemplate:
             self.operation_templates.append(operation_template)
             self.total_pipeline_operations[operation_template.operation_type] += 1
 
-    def convert_to_pipeline(self, pipeline, path: str = None, dict_fitted_operations: dict = None):
+    def convert_to_pipeline(self, pipeline: 'Pipeline', path: str = None, dict_fitted_operations: dict = None):
         if path is not None:
             path = os.path.abspath(os.path.dirname(path))
         visited_nodes = {}
@@ -316,6 +319,9 @@ class PipelineTemplate:
             except ModuleNotFoundError as ex:
                 self.log.warning(f'Could not load preprocessor from file `{preprocessor_file}` '
                                  f'due to legacy incompatibility. Please refit the preprocessor.')
+        else:
+            pipeline.preprocessor = \
+                DataPreprocessor() if self.metadata['use_input_preprocessing'] else DummyPreprocessor()
 
     def roll_pipeline_structure(self, operation_object: Union['OperationTemplate', 'AtomizedModelTemplate'],
                                 visited_nodes: dict, path: str = None, dict_fitted_operations: dict = None):
@@ -334,18 +340,10 @@ class PipelineTemplate:
 
         if operation_object.operation_type == atomized_model_type():
             atomized_model = operation_object.next_pipeline_template
-            if operation_object.nodes_from:
-                node = SecondaryNode(operation_type=atomized_model)
-            else:
-                node = PrimaryNode(operation_type=atomized_model)
+            node = PipelineNode(operation_type=atomized_model)
         else:
-            if operation_object.nodes_from:
-                node = SecondaryNode(operation_object.operation_type)
-            else:
-                node = PrimaryNode(operation_object.operation_type)
-
+            node = PipelineNode(operation_object.operation_type)
             node.parameters = operation_object.custom_params
-
             node.rating = operation_object.rating
 
         if hasattr(operation_object,
@@ -392,7 +390,7 @@ class PipelineTemplate:
                 return data_preprocessor_path
         else:
             # dictionary with bytes of fitted operations
-            if self.data_preprocessor:
+            if self.data_preprocessor is not None:
                 bytes_container = BytesIO()
                 joblib.dump(self.data_preprocessor, bytes_container)
                 return bytes_container
