@@ -3,6 +3,7 @@ from typing import Callable, Type, Union
 
 from hyperopt import tpe
 
+from fedot.core.constants import DEFAULT_TUNING_ITERATIONS_NUMBER
 from fedot.core.data.data import InputData
 from fedot.core.optimisers.composer_requirements import ComposerRequirements
 from fedot.core.optimisers.objective import PipelineObjectiveEvaluate
@@ -23,7 +24,7 @@ class TunerBuilder:
         self.validation_blocks = None
         self.n_jobs = -1
         self.metric: MetricsEnum = MetricByTask.get_default_quality_metrics(task.task_type)[0]
-        self.iterations = 100
+        self.iterations = DEFAULT_TUNING_ITERATIONS_NUMBER
         self.early_stopping_rounds = None
         self.timeout = timedelta(minutes=5)
         self.search_space = SearchSpace()
@@ -64,8 +65,14 @@ class TunerBuilder:
         self.early_stopping_rounds = early_stopping_rounds
         return self
 
-    def with_timeout(self, timeout: timedelta):
-        self.timeout = timeout
+    def with_timeout(self, timeout: Union[timedelta, float]):
+        if timeout in [-1, None]:
+            self.timeout = None
+        else:
+            if isinstance(timeout, timedelta):
+                self.timeout = timeout
+            elif isinstance(timeout, float):
+                self.timeout = timedelta(minutes=timeout)
         return self
 
     def with_eval_time_constraint(self, eval_time_constraint: Union[timedelta, int, float]):
@@ -85,7 +92,8 @@ class TunerBuilder:
         data_producer = DataSourceSplitter(self.cv_folds, self.validation_blocks).build(data)
         objective_evaluate = PipelineObjectiveEvaluate(objective, data_producer,
                                                        validation_blocks=self.validation_blocks,
-                                                       time_constraint=self.eval_time_constraint)
+                                                       time_constraint=self.eval_time_constraint,
+                                                       eval_n_jobs=self.n_jobs)  # because tuners are not parallelized
         tuner = self.tuner_class(objective_evaluate=objective_evaluate,
                                  iterations=self.iterations,
                                  early_stopping_rounds=self.early_stopping_rounds,
