@@ -42,7 +42,7 @@ class HyperoptTuner(ABC):
         self.search_space = search_space
         self.algo = algo
         self.n_jobs = n_jobs
-
+        self.was_tuned = False
         self.log = default_log(self)
 
     @abstractmethod
@@ -70,6 +70,7 @@ class HyperoptTuner(ABC):
         """
         pipeline.unfit()
         pipeline_fitness = self.objective_evaluate.evaluate(pipeline)
+
         metric_value = pipeline_fitness.value
         if not pipeline_fitness.valid:
             return self._default_metric_value
@@ -82,7 +83,7 @@ class HyperoptTuner(ABC):
         Args:
           pipeline: Pipeline to calculate objective
         """
-        self.log.info('Hyperparameters optimization start')
+        self.log.info('Hyperparameters optimization start: estimation of metric for initial pipeline')
 
         # Train pipeline
         self.init_pipeline = deepcopy(pipeline)
@@ -109,24 +110,26 @@ class HyperoptTuner(ABC):
         prefix_tuned_phrase = 'Return tuned pipeline due to the fact that obtained metric'
         prefix_init_phrase = 'Return init pipeline due to the fact that obtained metric'
 
-        # 5% deviation is acceptable
-        deviation = (self.init_metric / 100.0) * 5
-        init_metric = self.init_metric + deviation * np.sign(self.init_metric)
+        # 0.05% deviation is acceptable
+        deviation = (self.init_metric / 100.0) * 0.05
+        init_metric = self.init_metric + deviation * (-np.sign(self.init_metric))
         if self.obtained_metric is None:
             self.log.info(f'{prefix_init_phrase} is None. Initial metric is {abs(init_metric):.3f}')
             final_pipeline = self.init_pipeline
-
+            final_metric = self.init_metric
         elif self.obtained_metric <= init_metric:
             self.log.info(f'{prefix_tuned_phrase} {abs(self.obtained_metric):.3f} equal or '
-                          f'better than initial (+ 5% deviation) {abs(init_metric):.3f}')
+                          f'better than initial (+ 0.05% deviation) {abs(init_metric):.3f}')
             final_pipeline = tuned_pipeline
+            final_metric = self.obtained_metric
         else:
             self.log.info(f'{prefix_init_phrase} {abs(self.obtained_metric):.3f} '
-                          f'worse than initial (+ 5% deviation) {abs(init_metric):.3f}')
+                          f'worse than initial (+ 0.05% deviation) {abs(init_metric):.3f}')
             final_pipeline = self.init_pipeline
+            final_metric = self.init_metric
         self.log.message(f'Final pipeline: {final_pipeline.structure}')
-        if self.obtained_metric is not None:
-            self.log.message(f'Final metric: {abs(self.obtained_metric):.3f}')
+        if final_metric is not None:
+            self.log.message(f'Final metric: {abs(final_metric):.3f}')
         else:
             self.log.message(f'Final metric is None')
         return final_pipeline
