@@ -7,7 +7,7 @@ from fedot.core.log import default_log
 from fedot.core.visualisation.opt_history.arg_constraint_wrapper import ArgConstraintWrapper
 
 if TYPE_CHECKING:
-    from fedot.core.optimisers.opt_history_objects.opt_history import OptHistory
+    from fedot.core.visualisation.opt_viz import OptHistoryVisualizer
 
 
 class HistoryVisualization(metaclass=ArgConstraintWrapper):
@@ -24,10 +24,14 @@ class HistoryVisualization(metaclass=ArgConstraintWrapper):
     """
     constraint_checkers = []  # Use this for class-specific constraint checkers.
 
-    def __init__(self, history: OptHistory):
+    def __init__(self, visualizer: OptHistoryVisualizer):
+        self.visualizer = visualizer
+        self.history = visualizer.history
         self.log = default_log(self)
-        self.history = history
 
     @abstractmethod
     def visualize(self, *args, **kwargs):
         raise NotImplementedError()
+
+    def get_predefined_value(self, param: str):
+        return self.visualizer.visuals_params.get(param)
