@@ -1,5 +1,5 @@
 from copy import copy
-from typing import Dict, List, Union
+from typing import Union, Optional
 
 import numpy as np
 import pandas as pd
@@ -24,41 +24,32 @@ from fedot.core.operations.evaluation.operation_implementations.data_operations.
 )
 from fedot.core.repository.dataset_types import DataTypesEnum
 from fedot.core.repository.tasks import TaskTypesEnum
+from fedot.core.utils import copy_doc
+from fedot.preprocessing.base_preprocessing import BasePreprocessor
 from fedot.preprocessing.categorical import BinaryCategoricalPreprocessor
-from fedot.preprocessing.data_types import NAME_CLASS_INT, TableTypesCorrector
 from fedot.preprocessing.data_type_check import exclude_ts, exclude_multi_ts, exclude_image
+from fedot.preprocessing.data_types import NAME_CLASS_INT, TableTypesCorrector
 from fedot.preprocessing.structure import DEFAULT_SOURCE_NAME, PipelineStructureExplorer
+
 # The allowed percent of empty samples in features.
 # Example: 90% objects in features are 'nan', then drop this feature from data.
 ALLOWED_NAN_PERCENT = 0.9
 
 
-class DataPreprocessor:
+class DataPreprocessor(BasePreprocessor):
     """
     Class which contains methods for data preprocessing.
-    The class performs two types of preprocessing: obligatory and optional
+    The class performs two types of preprocessing: obligatory and optional.
 
-    obligatory - delete rows where nans in the target, remove features,
-    which full of nans, delete extra_spaces
+    obligatory - deletes rows where nans in the target, removes features,
+        which full of nans, deletes extra_spaces
     optional - depends on what operations are in the pipeline, gap-filling
-    is applied if there is no imputation operation in the pipeline, categorical
-    encoding is applied if there is no encoder in the structure of the pipeline etc.
+        is applied if there is no imputation operation in the pipeline, categorical
+        encoding is applied if there is no encoder in the structure of the pipeline etc.
     """
 
     def __init__(self):
-        # There was performed encoding for string target column or not
-        self.target_encoders: Dict[str, LabelEncoder] = {}
-        self.features_encoders: Dict[str, Union[OneHotEncodingImplementation, LabelEncodingImplementation]] = {}
-        self.use_label_encoder: bool = False
-        self.features_imputers: Dict[str, ImputationImplementation] = {}
-        self.ids_relevant_features: Dict[str, List[int]] = {}
-
-        # Cannot be processed due to incorrect types or large number of nans
-        self.ids_incorrect_features: Dict[str, List[int]] = {}
-        # Categorical preprocessor for binary categorical features
-        self.binary_categorical_processors: Dict[str, BinaryCategoricalPreprocessor] = {}
-        self.types_correctors: Dict[str, TableTypesCorrector] = {}
-        self.main_target_source_name = None
+        super().__init__()
 
         self.log = default_log(self)
 
@@ -73,19 +64,15 @@ class DataPreprocessor:
         self.__dict__.update(state)
 
     def _init_supplementary_preprocessors(self, data: Union[InputData, MultiModalData]):
-        """ Initialize helpers for preprocessor
-
-        :param data: data class with input data for preprocessing
         """
-        categorical_sources = list(self.binary_categorical_processors)
-        types_sources = list(self.types_correctors)
-        if len(categorical_sources) == len(types_sources) and types_sources:
+        Initializes helpers for preprocessor
+
+        Args:
+            data: with input data for preprocessing
+        """
+        if self.binary_categorical_processors and self.types_correctors:
             # Preprocessors have been already initialized
             return None
-        self.helpers_were_initialized = True
-
-        self.binary_categorical_processors = {}
-        self.types_correctors = {}
 
         if isinstance(data, InputData):
             self.binary_categorical_processors[DEFAULT_SOURCE_NAME] = BinaryCategoricalPreprocessor()
@@ -98,7 +85,12 @@ class DataPreprocessor:
             raise ValueError('Unknown type of data.')
 
     def _init_main_target_source_name(self, multi_data: MultiModalData):
-        """ Define for MultiModal data branches with main target and side ones """
+        """
+        Defines main_target_source_name for MultiModal data branches with main target and the side ones
+        
+        Args:
+            multi_data: `MultiModalData`
+        """
         if self.main_target_source_name is not None:
             # Target name has been already defined
             return None
@@ -108,12 +100,8 @@ class DataPreprocessor:
                 self.main_target_source_name = data_source_name
                 break
 
-    def obligatory_prepare_for_fit(self, data: Union[InputData, MultiModalData]):
-        """
-        Perform obligatory preprocessing for pipeline fit method.
-        It includes removing features full of nans, extra spaces in features deleting,
-        drop rows where target cells are none
-        """
+    @copy_doc(BasePreprocessor.obligatory_prepare_for_fit)
+    def obligatory_prepare_for_fit(self, data: Union[InputData, MultiModalData]) -> Union[InputData, MultiModalData]:
         # TODO add advanced gapfilling for time series and advanced gap-filling
         self._init_supplementary_preprocessors(data)
 
@@ -126,11 +114,12 @@ class DataPreprocessor:
                 data[data_source_name] = self._prepare_obligatory_unimodal_for_fit(values,
                                                                                    source_name=data_source_name)
 
-        self.mark_as_preprocessed(data)
+        BasePreprocessor.mark_as_preprocessed(data)
         return data
 
-    def obligatory_prepare_for_predict(self, data: Union[InputData, MultiModalData]):
-        """ Perform obligatory preprocessing for pipeline predict method """
+    @copy_doc(BasePreprocessor.obligatory_prepare_for_predict)
+    def obligatory_prepare_for_predict(self, data: Union[InputData, MultiModalData]) -> Union[
+        InputData, MultiModalData]:
         if isinstance(data, InputData):
             data = self._prepare_obligatory_unimodal_for_predict(data, source_name=DEFAULT_SOURCE_NAME)
 
@@ -139,15 +128,12 @@ class DataPreprocessor:
                 data[data_source_name] = self._prepare_obligatory_unimodal_for_predict(values,
                                                                                        source_name=data_source_name)
 
-        self.mark_as_preprocessed(data)
+        BasePreprocessor.mark_as_preprocessed(data)
         return data
 
-    def optional_prepare_for_fit(self, pipeline, data: Union[InputData, MultiModalData]):
-        """ Launch preprocessing operations if it is necessary for pipeline fitting
-
-        :param pipeline: pipeline to prepare data for
-        :param data: data to preprocess
-        """
+    @copy_doc(BasePreprocessor.optional_prepare_for_fit)
+    def optional_prepare_for_fit(self, pipeline, data: Union[InputData, MultiModalData]) -> Union[
+        InputData, MultiModalData]:
         self._init_supplementary_preprocessors(data)
 
         if isinstance(data, InputData):
@@ -158,15 +144,12 @@ class DataPreprocessor:
             for data_source_name, values in data.items():
                 self._prepare_optional(pipeline, values, data_source_name)
 
+        BasePreprocessor.mark_as_preprocessed(data, is_obligatory=False)
         return data
 
-    def optional_prepare_for_predict(self, pipeline, data: Union[InputData, MultiModalData]):
-        """ Launch preprocessing operations if it is necessary for pipeline predict stage.
-        Preprocessor should already must be fitted.
-
-        :param pipeline: pipeline to prepare data for
-        :param data: data to preprocess
-        """
+    @copy_doc(BasePreprocessor.optional_prepare_for_predict)
+    def optional_prepare_for_predict(self, pipeline, data: Union[InputData, MultiModalData]) -> Union[
+        InputData, MultiModalData]:
         if isinstance(data, InputData):
             self._prepare_optional(pipeline, data, DEFAULT_SOURCE_NAME)
         else:
@@ -174,10 +157,17 @@ class DataPreprocessor:
             for data_source_name, values in data.items():
                 self._prepare_optional(pipeline, values, data_source_name)
 
+        BasePreprocessor.mark_as_preprocessed(data, is_obligatory=False)
         return data
 
-    def take_only_correct_features(self, data: InputData, source_name: str):
-        """ Take only correct features in the table """
+    def _take_only_correct_features(self, data: InputData, source_name: str):
+        """
+        Takes only correct features from the table
+        
+        Args:
+            data: to take correct features from
+            source_name: name of the data source node
+        """
         current_relevant_ids = self.ids_relevant_features[source_name]
         if current_relevant_ids:
             data.features = data.features[:, current_relevant_ids]
@@ -186,8 +176,17 @@ class DataPreprocessor:
     @exclude_multi_ts
     @exclude_image
     def _prepare_obligatory_unimodal_for_fit(self, data: InputData, source_name: str) -> InputData:
-        """ Method process InputData for pipeline fit method """
-        if data.supplementary_data.was_preprocessed:
+        """
+        Processes InputData for pipeline fit method
+        
+        Args:
+            data: to be preprocessed
+            source_name: name of the data source node
+        
+        Returns:
+            obligatory-prepared ``data``
+        """
+        if data.supplementary_data.obligatorily_preprocessed:
             # Preprocessing was already done - return data
             return data
 
@@ -200,7 +199,7 @@ class DataPreprocessor:
 
         # Find incorrect features which must be removed
         self._find_features_full_of_nans(data, source_name)
-        self.take_only_correct_features(data, source_name)
+        self._take_only_correct_features(data, source_name)
         data = self._drop_rows_with_nan_in_target(data)
 
         # Column types processing - launch after correct features selection
@@ -209,7 +208,8 @@ class DataPreprocessor:
             data = self._drop_rows_with_nan_in_target(data)
 
         # Train Label Encoder for categorical target if necessary and apply it
-        self._train_target_encoder(data, source_name)
+        if source_name not in self.target_encoders:
+            self._train_target_encoder(data, source_name)
         data.target = self._apply_target_encoding(data, source_name)
 
         # TODO andreygetmanov target encoding must be obligatory for all data types
@@ -219,8 +219,7 @@ class DataPreprocessor:
         elif data_type_is_table(data):
             data = self._clean_extra_spaces(data)
             # Process binary categorical features
-            self.binary_categorical_processors[source_name].fit(data)
-            data = self.binary_categorical_processors[source_name].transform(data)
+            data = self.binary_categorical_processors[source_name].fit_transform(data)
 
         return data
 
@@ -228,8 +227,17 @@ class DataPreprocessor:
     @exclude_multi_ts
     @exclude_image
     def _prepare_obligatory_unimodal_for_predict(self, data: InputData, source_name: str) -> InputData:
-        """ Method process InputData for pipeline predict method """
-        if data.supplementary_data.was_preprocessed:
+        """
+        Processes InputData for pipeline predict method
+        
+        Args:
+            data: to be preprocessed
+            source_name: name of the data source node
+        
+        Returns:
+            obligatory-prepared data
+        """
+        if data.supplementary_data.obligatorily_preprocessed:
             # Preprocessing was already done - return data
             return data
 
@@ -241,7 +249,7 @@ class DataPreprocessor:
         replace_inf_with_nans(data)
 
         # Perform preprocessing for types - launch after correct features selection
-        self.take_only_correct_features(data, source_name)
+        self._take_only_correct_features(data, source_name)
         self.types_correctors[source_name].convert_data_for_predict(data)
 
         if data_type_is_text(data):
@@ -253,29 +261,35 @@ class DataPreprocessor:
         return data
 
     def _prepare_optional(self, pipeline, data: InputData, source_name: str):
-        """ Perform optional fitting/preprocessing for unimodal data """
-        if not data_type_is_table(data):
+        """
+        Performs optional fitting/preprocessing for unimodal data
+        
+        Args:
+            pipeline: determines if optional preprocessing is needed
+            data: to be preprocessed
+            source_name: name of the data source node
+        """
+        if not data_type_is_table(data) or data.supplementary_data.optionally_preprocessed:
             return data
 
-        if data_has_missing_values(data):
-            # Data contains missing values
-            has_imputer = PipelineStructureExplorer.\
-                check_structure_by_tag(pipeline, tag_to_check='imputation', source_name=source_name)
-            if not has_imputer:
-                data = self._apply_imputation_unidata(data, source_name)
-
-        if data_has_categorical_features(data):
-            # Data contains categorical features values
-            has_encoder = PipelineStructureExplorer.\
-                check_structure_by_tag(pipeline, tag_to_check='encoding', source_name=source_name)
-            if not has_encoder:
-                data = self._apply_categorical_encoding(data, source_name)
+        for has_problems, tag_to_check, action_if_no_tag in [
+            (data_has_missing_values, 'imputation', self._apply_imputation_unidata),
+            (data_has_categorical_features, 'encoding', self._apply_categorical_encoding)
+        ]:
+            if has_problems(data):
+                # Data contains missing values
+                has_tag = PipelineStructureExplorer.check_structure_by_tag(
+                    pipeline, tag_to_check=tag_to_check, source_name=source_name)
+                if not has_tag:
+                    data = action_if_no_tag(data, source_name)
 
     def _find_features_full_of_nans(self, data: InputData, source_name: str):
-        """ Find features with more than ALLOWED_NAN_PERCENT nan's
+        """
+        Finds features with more than ALLOWED_NAN_PERCENT of nan's
 
-        :param data: data to find columns with nan values
-        :param source_name: name of data source node
+        Args:
+            data: data to find columns with nan values
+            source_name: name of the data source node
         """
         # Initialize empty lists to fill it with indices
         self.ids_relevant_features[source_name] = []
@@ -292,8 +306,16 @@ class DataPreprocessor:
                 self.ids_incorrect_features[source_name].append(i)
 
     @staticmethod
-    def _drop_rows_with_nan_in_target(data: InputData):
-        """ Drop rows where in target column there are nans """
+    def _drop_rows_with_nan_in_target(data: InputData) -> InputData:
+        """
+        Drops rows with nans in target column
+        
+        Args:
+            data: to be modified
+        
+        Returns:
+            modified ``data``
+        """
         features = data.features
         target = data.target
 
@@ -313,9 +335,16 @@ class DataPreprocessor:
         return data
 
     @staticmethod
-    def _clean_extra_spaces(data: InputData):
-        """ Remove extra spaces from data.
-            Transform cells in columns from ' x ' to 'x'
+    def _clean_extra_spaces(data: InputData) -> InputData:
+        """
+        Removes extra spaces from data.
+            Transforms cells in columns from ' x ' to 'x'
+        
+        Args:
+            data: to be stripped
+
+        Returns:
+            cleaned ``data``
         """
         features = pd.DataFrame(data.features)
         features = features.applymap(lambda x: x.strip() if isinstance(x, str) else x)
@@ -323,14 +352,8 @@ class DataPreprocessor:
         data.features = np.array(features)
         return data
 
+    @copy_doc(BasePreprocessor.label_encoding_for_fit)
     def label_encoding_for_fit(self, data: InputData, source_name: str = DEFAULT_SOURCE_NAME):
-        """
-        Encode categorical features to numerical using LabelEncoder. In additional,
-        save encoders to use later for prediction data.
-
-        :param data: data to transform
-        :param source_name: name of data source node
-        """
         if data_has_categorical_features(data):
             encoder = self.features_encoders.get(source_name)
             if not isinstance(encoder, LabelEncodingImplementation) or encoder is None:
@@ -343,8 +366,8 @@ class DataPreprocessor:
             data.features = encoder_output.predict
             data.supplementary_data = encoder_output.supplementary_data
 
+    @copy_doc(BasePreprocessor.cut_dataset)
     def cut_dataset(self, data: InputData, border: int):
-        """ Cutting large dataset based on border (number of objects to remain) """
         self.log.info("Cut dataset due to it size is large")
         # TODO: don't shuffle the data here, because it is done in GPComposer
         data.shuffle()
@@ -352,10 +375,15 @@ class DataPreprocessor:
         data.features = data.features[:border]
         data.target = data.target[:border]
 
-    def _apply_imputation_unidata(self, data: InputData, source_name: str):
-        """ Fill in the gaps in the data inplace.
+    def _apply_imputation_unidata(self, data: InputData, source_name: str) -> InputData:
+        """
+        Fills in the gaps in the provided data.
 
-        :param data: data for fill in the gaps
+        Args:
+            data: data for fill in the gaps
+        
+        Returns:
+            imputed ``data``
         """
         imputer = self.features_imputers.get(source_name)
         if not imputer:
@@ -367,13 +395,17 @@ class DataPreprocessor:
         data.features = output_data.predict
         return data
 
-    def _apply_categorical_encoding(self, data: InputData, source_name: str):
+    def _apply_categorical_encoding(self, data: InputData, source_name: str) -> InputData:
         """
         Transforms the data inplace. Uses the same transformations as for the training data if trained already.
         Otherwise fits appropriate encoder and converts data's categorical features with it.
 
-        :param data: data to transformation
-        :param source_name: name of data source node
+        Args:
+            data: data to be transformed
+            source_name: name of the data source node
+        
+        Returns:
+            encoded ``data``
         """
         encoder = self.features_encoders.get(source_name)
         if encoder is None:
@@ -387,7 +419,13 @@ class DataPreprocessor:
         return data
 
     def _train_target_encoder(self, data: InputData, source_name: str):
-        """ Convert string categorical target into integer column using LabelEncoder """
+        """
+        Trains `LabelEncoder` if the ``data``'s target consists of strings
+        
+        Args:
+            data: data to be encoded
+            source_name: name of the data source node
+        """
         categorical_ids, _ = find_categorical_columns(data.target, data.supplementary_data.column_types['target'])
 
         if categorical_ids:
@@ -396,24 +434,32 @@ class DataPreprocessor:
             target_encoder.fit(data.target)
             self.target_encoders[source_name] = target_encoder
 
-    def _apply_target_encoding(self, data: InputData, source_name: str) -> np.array:
-        """ Apply trained encoder for target column
+    def _apply_target_encoding(self, data: InputData, source_name: str) -> np.ndarray:
+        """
+        Applies trained encoder for target column if it is needed
 
         For example, target [['red'], ['green'], ['red']] will be converted into
         [[0], [1], [0]]
+
+        Args:
+            data: data to be encoded
+            source_name: name of the data source node
+        
+        Returns:
+            encoded ``data``'s target
         """
-        if source_name in self.target_encoders:
+        encoder = self.target_encoders.get(source_name)
+        encoded_target = data.target
+        if encoder is not None:
             # Target encoders have already been fitted
             data.supplementary_data.column_types['target'] = [NAME_CLASS_INT]
-            encoded_target = self.target_encoders[source_name].transform(data.target)
+            encoded_target = encoder.transform(data.target)
             if len(encoded_target.shape) == 1:
                 encoded_target = encoded_target.reshape((-1, 1))
-            return encoded_target
-        else:
-            return data.target
+        return encoded_target
 
-    def apply_inverse_target_encoding(self, column_to_transform: np.array) -> np.array:
-        """ Apply inverse Label Encoding operation for target column """
+    @copy_doc(BasePreprocessor.apply_inverse_target_encoding)
+    def apply_inverse_target_encoding(self, column_to_transform: np.ndarray) -> np.ndarray:
         main_target_source_name = self._determine_target_converter()
 
         if main_target_source_name in self.target_encoders:
@@ -429,15 +475,17 @@ class DataPreprocessor:
             if len(transformed.shape) == 1:
                 transformed = transformed.reshape((-1, 1))
             return transformed
-        else:
-            # Return source column
-            return column_to_transform
+        # Else just return source column
+        return column_to_transform
 
     def _determine_target_converter(self):
         """
-        For inverse target transformation there is a need to determine
-        which target encoder to use (if there are several targets in
-        single MultiModal pipeline).
+        Determines which encoder target to use.
+        Applicable for inverse target transformation (if there are several targets in
+            single MultiModal pipeline).
+        
+        Returns:
+            selected data source name
         """
         # Choose data source node name with main target
         if self.main_target_source_name is None:
@@ -448,8 +496,14 @@ class DataPreprocessor:
     @staticmethod
     def _correct_shapes(data: InputData) -> InputData:
         """
-        Correct shapes of tabular data or time series: tabular must be
-        two-dimensional arrays, text - array of (n, 1), time series - one-dim array
+        Corrects shapes of tabular data or time series.
+        
+        Args:
+            data: time series or tabular. In the first case must be 1d-array, in the second case must be
+                two-dimensional arrays or array of (n, 1) for texts.
+        
+        Returns:
+            corrected tabular data
         """
         if data_type_is_table(data) or data.data_type is DataTypesEnum.multi_ts:
             if np.ndim(data.features) < 2:
@@ -466,6 +520,7 @@ class DataPreprocessor:
         return data
 
     @staticmethod
+    @copy_doc(BasePreprocessor.convert_indexes_for_fit)
     def convert_indexes_for_fit(pipeline, data: Union[InputData, MultiModalData]):
         if isinstance(data, MultiModalData):
             for data_source_name in data:
@@ -478,6 +533,7 @@ class DataPreprocessor:
             return data
 
     @staticmethod
+    @copy_doc(BasePreprocessor.convert_indexes_for_predict)
     def convert_indexes_for_predict(pipeline, data: Union[InputData, MultiModalData]):
         if isinstance(data, MultiModalData):
             for data_source_name in data:
@@ -490,56 +546,22 @@ class DataPreprocessor:
             return data
 
     @staticmethod
-    def restore_index(input_data: InputData, result: OutputData):
-        if isinstance(input_data, InputData):
-            if input_data.supplementary_data.non_int_idx is not None:
-                result.idx = copy(input_data.supplementary_data.non_int_idx)
-                result.supplementary_data.non_int_idx = copy(input_data.idx)
+    @copy_doc(BasePreprocessor.restore_index)
+    def restore_index(input_data: Optional[InputData], result: OutputData):
+        if input_data is not None and input_data.supplementary_data.non_int_idx is not None:
+            result.idx = copy(input_data.supplementary_data.non_int_idx)
+            result.supplementary_data.non_int_idx = copy(input_data.idx)
         return result
 
-    @staticmethod
-    def mark_as_preprocessed(data: Union[InputData, MultiModalData]):
-        if isinstance(data, InputData):
-            data.supplementary_data.was_preprocessed = True
-        else:
-            # Multimodal data
-            for values in data.values():
-                values.supplementary_data.was_preprocessed = True
+    @copy_doc(BasePreprocessor.update_indices_for_time_series)
+    def update_indices_for_time_series(self, test_data: Union[InputData, MultiModalData]):
+        if test_data.task.task_type is not TaskTypesEnum.ts_forecasting:
+            return test_data
 
-
-def merge_preprocessors(api_preprocessor: DataPreprocessor,
-                        pipeline_preprocessor: DataPreprocessor) -> DataPreprocessor:
-    """
-    Combining two preprocessor objects. One is the preprocessor from the API,
-    the second is the preprocessor from the obtained pipeline
-    """
-    # Take all obligatory data preprocessing from API
-    new_data_preprocessor = api_preprocessor
-
-    # Update optional preprocessing (take it from obtained pipeline)
-    if not new_data_preprocessor.features_encoders:
-        # Store features encoder from obtained pipeline because in API there are no encoding
-        new_data_preprocessor.features_encoders = pipeline_preprocessor.features_encoders
-    return new_data_preprocessor
-
-
-def update_indices_for_time_series(test_data: Union[InputData, MultiModalData]):
-    """ Replace indices for time series for predict stage """
-    if test_data.task.task_type is not TaskTypesEnum.ts_forecasting:
-        return test_data
-
-    if isinstance(test_data, MultiModalData):
-        # Process multimodal data - change indices in every data block
-        for input_data in test_data.values():
+        values = [test_data] if isinstance(test_data, InputData) else test_data.values()
+        for input_data in values:
             forecast_len = input_data.task.task_params.forecast_length
             if forecast_len < len(input_data.idx):
-                # Indices incorrect - there is a need to reassign them
                 last_id = len(input_data.idx)
                 input_data.idx = np.arange(last_id, last_id + input_data.task.task_params.forecast_length)
-    else:
-        # Simple input data
-        forecast_len = test_data.task.task_params.forecast_length
-        if forecast_len < len(test_data.idx):
-            last_id = len(test_data.idx)
-            test_data.idx = np.arange(last_id, last_id + test_data.task.task_params.forecast_length)
-    return test_data
+        return test_data
